==> Task-BeLike-RWP-0.231750.tar.gz: Task-BeLike-RWP-0.231750/lib/Task/BeLike/RWP.pm <==
# ABSTRACT: Perl modules bundle to install from CPAN

use v5.37.9;


package Task::BeLike::RWP;

# TODO: FIX :list

__END__

=pod

=encoding UTF-8

=head1 NAME

Task::BeLike::RWP - Perl modules bundle to install from CPAN

=head1 VERSION

version 0.231750

=head1 SYNOPSIS

cpanm Task::BeLike::RWP

=head1 DESCRIPTION

=head2 MODULES

The following Perl modules will be installed as part of this bundle.

=over 4

=item L<Path::Tiny> (L<GitHub|https://github.com/dagolden/Path-Tiny>)

OOP file management

=item L<System::Command> (L<GitHub|https://github.com/book/System-Command>)

Execute commands in OOP style

=item L<Net::DNS> (L<GitHub|https://github.com/NLnetLabs/Net-DNS>)

OOP DNS resolver and the rest

=item L<Dist::Zilla> (L<GitHub|https://github.com/rjbs/Dist-Zilla>)

Perl distribution management and release

=item L<Config::General> (L<GitHub|https://github.com/TLINDEN/Config-General>)

General configuration file parser

=item L<DBI> (L<GitHub|https://github.com/perl5-dbi/dbi>)

Database connection and manipulation

=item L<SQL::Abstract> (L<GitHub|https://github.com/dbsrgits/sql-abstract>)

SQL command abstraction in OOP style with useful statement costructing methods

=item L<URI> (L<GitHub|https://github.com/libwww-perl/URI>)

General URI class to handle URL's and the like

=item L<Clipboard> (L<GitHub|https://github.com/shlomif/Clipboard>)

Cross-platform clipboard management

=item L<PadWalker> (L<GitHub|https://github.com/robinhouston/PadWalker>)

Supported by Perl Debugger as the C<y> command

=item L<Data::Printer> (L<GitHub|https://github.com/garu/Data-Printer>)

Aids in debugging by displaying Perl data structures

=item L<Log::Log4perl> (L<GitHub|https://github.com/mschilli/log4perl>)

Perl logging framework

=item L<IO::Tee> (L<GitHub|https://github.com/neilb/IO-Tee>)

Tee file handle

=item L<Domain::PublicSuffix> (L<GitHub|https://github.com/nmelnick/domain-publicsuffix>)

Get to the domain root, by Mozilla

=item L<Net::IP::XS> (L<GitHub|https://github.com/tomhrr/p5-Net-IP-XS>)

IP class

=item L<XML::RSS> (L<GitHub|https://github.com/shlomif/perl-XML-RSS>)

RSS parser. Requires the C<libexpat1-dev> package to be installed.

=item L<Yaml::XS> (L<GitHub|https://github.com/ingydotnet/yaml-libyaml-pm>>)

=item L<Rex> (L<GitHub|https://github.com/RexOps/Rex>)

=item L<Number::Bytes::Human> (L<GitHub|https://github.com/aferreira/cpan-Number-Bytes-Human)

=back

=head1 AUTHOR

Elvin Aslanov <rwp.primary@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2023 by Elvin Aslanov.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

==> Task-BeLike-RWP-0.231770.tar.gz: Task-BeLike-RWP-0.231770/lib/Task/BeLike/RWP.pm <==
# ABSTRACT: Perl modules bundle to install from CPAN

use v5.37.9;


package Task::BeLike::RWP;

# TODO: FIX :list

__END__

=pod

=encoding UTF-8

=head1 NAME

Task::BeLike::RWP - Perl modules bundle to install from CPAN

=head1 VERSION

version 0.231770

=head1 SYNOPSIS

cpanm Task::BeLike::RWP

=head1 DESCRIPTION

=head2 MODULES

The following Perl modules will be installed as part of this bundle.

=over 4

=item L<Path::Tiny> (L<GitHub|https://github.com/dagolden/Path-Tiny>)

OOP file management

=item L<System::Command> (L<GitHub|https://github.com/book/System-Command>)

Execute commands in OOP style

=item L<Net::DNS> (L<GitHub|https://github.com/NLnetLabs/Net-DNS>)

OOP DNS resolver and the rest

=item L<Dist::Zilla> (L<GitHub|https://github.com/rjbs/Dist-Zilla>)

Perl distribution management and release

=item L<Config::General> (L<GitHub|https://github.com/TLINDEN/Config-General>)

General configuration file parser

=item L<DBI> (L<GitHub|https://github.com/perl5-dbi/dbi>)

Database connection and manipulation

=item L<SQL::Abstract> (L<GitHub|https://github.com/dbsrgits/sql-abstract>)

SQL command abstraction in OOP style with useful statement costructing methods

=item L<URI> (L<GitHub|https://github.com/libwww-perl/URI>)

General URI class to handle URL's and the like

=item L<Clipboard> (L<GitHub|https://github.com/shlomif/Clipboard>)

Cross-platform clipboard management

=item L<PadWalker> (L<GitHub|https://github.com/robinhouston/PadWalker>)

Supported by Perl Debugger as the C<y> command

=item L<Data::Printer> (L<GitHub|https://github.com/garu/Data-Printer>)

Aids in debugging by displaying Perl data structures

=item L<Log::Log4perl> (L<GitHub|https://github.com/mschilli/log4perl>)

Perl logging framework

=item L<IO::Tee> (L<GitHub|https://github.com/neilb/IO-Tee>)

Tee file handle

=item L<Domain::PublicSuffix> (L<GitHub|https://github.com/nmelnick/domain-publicsuffix>)

Get to the domain root, by Mozilla

=item L<Net::IP::XS> (L<GitHub|https://github.com/tomhrr/p5-Net-IP-XS>)

IP class

=item L<XML::RSS> (L<GitHub|https://github.com/shlomif/perl-XML-RSS>)

RSS parser. Requires the C<libexpat1-dev> package to be installed.

=item L<Yaml::XS> (L<GitHub|https://github.com/ingydotnet/yaml-libyaml-pm>)

YAML markup parser using C<libyaml> C library

=item L<Rex> (L<GitHub|https://github.com/RexOps/Rex>)

SSH-based automation framework in Perl

=item L<Number::Bytes::Human> (L<GitHub|https://github.com/aferreira/cpan-Number-Bytes-Human>)

Human-redable bytes

=back

=head1 AUTHOR

Elvin Aslanov <rwp.primary@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2023 by Elvin Aslanov.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
